Enum jsonwebtoken::errors::ErrorKind[]

pub enum ErrorKind {
    Msg(String),
    Unspecified(Unspecified),
    Base64(DecodeError),
    Json(Error),
    Utf8(FromUtf8Error),
    InvalidToken,
    InvalidSignature,
    InvalidKey,
    ExpiredSignature,
    InvalidIssuer,
    InvalidAudience,
    InvalidSubject,
    InvalidIssuedAt,
    ImmatureSignature,
    InvalidAlgorithm,
    // some variants omitted
}

The kind of an error.

Variants

A convenient variant for String.

An error happened while signing/verifying a token with RSA

An error happened while decoding some base64 text

An error happened while serializing/deserializing JSON

An error happened while trying to convert the result of base64 decoding to a String

When a token doesn't have a valid JWT shape

When the signature doesn't match

When the secret given is not a valid RSA key

When a token’s exp claim indicates that it has expired

When a token’s iss claim does not match the expected issuer

When a token’s aud claim does not match one of the expected audience values

When a token’s aud claim does not match one of the expected audience values

When a token’s iat claim is in the future

When a token’s nbf claim represents a time in the future

When the algorithm in the header doesn't match the one passed to decode

Methods

impl ErrorKind

A string describing the error kind.